summaryrefslogtreecommitdiffstats
path: root/kig/objects/object_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kig/objects/object_imp.h')
-rw-r--r--kig/objects/object_imp.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kig/objects/object_imp.h b/kig/objects/object_imp.h
index eaf29328..20484ecf 100644
--- a/kig/objects/object_imp.h
+++ b/kig/objects/object_imp.h
@@ -87,7 +87,7 @@ typedef unsigned int uint;
*/
class ObjectImpType
{
- const ObjectImpType* mparent;
+ const ObjectImpType* mtqparent;
const char* minternalname;
const char* mtranslatedname;
const char* mselectstatement;
@@ -126,12 +126,12 @@ public:
* hideastatement is a translatable string like "Hide a Segment"
*
* All translatable strings should have
* I18N_NOOP around them ! @param parent is the ObjectImpType of
* your parent ObjectImp type. Never give 0 as parent, except for
* the top ObjectImp ObjectImpType..
*/
ObjectImpType(
- const ObjectImpType* parent, const char* internalname,
+ const ObjectImpType* tqparent, const char* internalname,
const char* translatedname,
const char* selectstatement,
const char* selectnamestatement,
@@ -170,7 +170,7 @@ public:
* Returns a translatable string of the form "Select point %1". %1
* will be filled in by whomever calls this function with the name
* of the object in question. This function should be used as
- * follows: i18n( x->selectNameStatement() ).arg( xname ).
+ * follows: i18n( x->selectNameStatement() ).tqarg( xname ).
*/
const char* selectNameStatement() const;
@@ -268,7 +268,7 @@ public:
virtual ObjectImp* transform( const Transformation& t ) const = 0;
virtual void draw( KigPainter& p ) const = 0;
- virtual bool contains( const Coordinate& p, int width,
+ virtual bool tqcontains( const Coordinate& p, int width,
const KigWidget& si ) const = 0;
virtual bool inRect( const Rect& r, int width,
const KigWidget& si ) const = 0;
@@ -126,12 +126,12 @@ public:
*
* All translatable strings should have
- * I18N_NOOP around them ! @param parent is the ObjectImpType of
- * your parent ObjectImp type. Never give 0 as parent, except for
+ * I18N_NOOP around them ! @param tqparent is the ObjectImpType of
+ * your tqparent ObjectImp type. Never give 0 as tqparent, except for
* the top ObjectImp ObjectImpType..
*/